---
id: 배열크기조정
title: 2) 배열의 크기 조정하기
---

## 문제 제기

일정한 크기의 배열이 주어졌을 때, 그 크기를 키우려면 어떻게 해야 할까요?

단순하게 현재 배열이 저장되어 있는 메모리 위치의 바로 옆에 일정 크기의 메모리를 더 덧붙이면 되겠지만, 실제로는 다른 데이터가 저장되어 있을 확률이 높습니다.

> 크기 6의 배열을 메모리 0x1~6에 할당하고, 1개의 아이템을 추가하여(총 7개) 재할당하려고 옆에 덧붙이려고 했으나 0x7 주소에 다른 값이 들어있어서 공간이 없다.

따라서 안전하게 **새로운 공간에 큰 크기의 메모리를 다시 할당**하고 기존 배열의 값들을 하나씩 옮겨줘야 합니다.

따라서 이런 작업은 **O(n)**, 즉 배열의 크기 n만큼의 실행 시간이 소요될 것입니다.

> 7개의 아이템이 들어갈 메모리 주소를 찾아서 그쪽으로 옮깁니다.

## Realloc을 사용하여 재할당하기

```c
#include <stdio.h>
#include <stdlib.h>

int main(void)
{
    int *list = malloc(3 * sizeof(int));
    if (list == NULL)
    {
        return 1;
    }

    list[0] = 1;
    list[1] = 2;
    list[2] = 3;

    // tmp 포인터에 메모리를 할당하고 list의 값 복사
    int *tmp = realloc(list, 4 * sizeof(int));
    if (tmp == NULL)
    {
        return 1;
    }

    // list가 tmp와 같은 곳을 가리키도록 지정
    list = tmp;

    // 새로운 list의 네 번째 값 저장
    list[3] = 4;

    // list의 값 확인
    for (int i = 0; i < 4; i++)
    {
        printf("%i\n", list[i]);
    }

    //list 의 메모리 초기화
    free(list);
}
```

## 생각해보기

이미 할당된 메모리의 크기를 조절할 때 임시 메모리를 새로 할당해줘야 하는 이유는 무엇인가요?

> 메모리 옆의 공간들이 이미 할당되었을 가능성이 있기 때문이다.

:::note
written by [CaesiumY](https://github.com/CaesiumY)
:::
